==> haskell-generically-0.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-IH8NpZ1vmjyFZUnjdxyoUy
key:                  generically-0.1.1-IH8NpZ1vmjyFZUnjdxyoUy
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  b1888a0ebde5a44717b6897455b6cfde
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-IH8NpZ1vmjyFZUnjdxyoUy
depends:
    base-4.17.2.1 base-orphans-0.8.8.2-DkMcjPMpDeZAO9Gbq4jAac

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generically-0.1.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-LsuHa91PIOL4IhL6gzRMQe
key:                  generically-0.1.1-LsuHa91PIOL4IhL6gzRMQe
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  5434e760af066b4354d452b1da634075
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-LsuHa91PIOL4IhL6gzRMQe
depends:
    base-4.17.2.1 base-orphans-0.8.8.2-LPpbH1Usu5ACvecPbFikKh

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
